@@ -19,7 +19,7 @@ plot.see_check_collinearity <- function(x,
                                         data = NULL,
                                         colors = c("#3aaf85", "#1b6ca8", "#cd201f"),
                                         size_point = 3.5,
-                                        size_line = 0.8,
+                                        linewidth = 0.8,
                                         size_title = 12,
                                         size_axis_title = base_size,
                                         base_size = 10,
@@ -38,14 +38,11 @@ plot.see_check_collinearity <- function(x,
   dat$group[dat$VIF >= 5 & dat$VIF < 10] <- "moderate"
   dat$group[dat$VIF >= 10] <- "high"
 
-  dat <- datawizard::data_rename(
+  dat <- datawizard::data_select(
     dat,
-    pattern = c("Term", "VIF", "SE_factor", "Component"),
-    replacement = c("x", "y", "se", "facet")
+    select = c(x = "Term", y = "VIF", facet = "Component", group = "group")
   )
 
-  dat <- datawizard::data_select(dat, select = c("x", "y", "facet", "group"))
-
   if (insight::n_unique(dat$facet) <= 1) {
     dat$facet <- NULL
   }
@@ -53,7 +50,7 @@ plot.see_check_collinearity <- function(x,
   .plot_diag_vif(
     dat,
     size_point = size_point,
-    size_line = size_line,
+    linewidth = linewidth,
     size_title = size_title,
     size_axis_title = size_axis_title,
     base_size = base_size,
@@ -66,7 +63,7 @@ plot.see_check_collinearity <- function(x,
 
 .plot_diag_vif <- function(x,
                            size_point,
-                           size_line,
+                           linewidth,
                            theme_style = theme_lucid,
                            size_title = 12,
                            size_axis_title = 10,
@@ -132,7 +129,7 @@ plot.see_check_collinearity <- function(x,
   if (!is.null(ci_data)) {
     p <- p +
       ggplot2::geom_linerange(
-        linewidth = size_line,
+        linewidth = linewidth,
         na.rm = TRUE
       ) +
       ggplot2::geom_segment(
