@@ -51,8 +51,6 @@ data_plot.compare_performance <- function(x, data = NULL, ...) {
 }
 
 
-
-
 # Plot --------------------------------------------------------------------
 #' Plot method for comparing model performances
 #'
@@ -74,7 +72,7 @@ data_plot.compare_performance <- function(x, data = NULL, ...) {
 #' plot(result)
 #'
 #' @export
-plot.see_compare_performance <- function(x, size_line = 1, ...) {
+plot.see_compare_performance <- function(x, linewidth = 1, ...) {
   # We may think of plotting the "performance scores" as bar plots,
   # however, the "worst" model always has a score of zero, so no bar
   # is shown - this is rather confusing. One option might be to only
@@ -104,7 +102,7 @@ plot.see_compare_performance <- function(x, size_line = 1, ...) {
     group = .data$Model,
     fill = .data$Model
   )) +
-    geom_polygon(linewidth = size_line, alpha = 0.05) +
+    geom_polygon(linewidth = linewidth, alpha = 0.05) +
     coord_radar() +
     scale_y_continuous(limits = c(0, 1), labels = NULL) +
     add_plot_attributes(x) +
