@@ -15,8 +15,8 @@
 #' plot(result)
 #' @export
 plot.see_equivalence_test <- function(x,
-                                      rope_color = "#0171D3",
-                                      rope_alpha = 0.2,
+                                      color_rope = "#0171D3",
+                                      alpha_rope = 0.2,
                                       show_intercept = FALSE,
                                       n_columns = 1,
                                       ...) {
@@ -132,32 +132,32 @@ plot.see_equivalence_test <- function(x,
   if ("legend.title" %in% names(add.args)) legend.title <- eval(add.args[["legend.title"]])
   if ("labels" %in% names(add.args)) axis_labels <- eval(add.args[["labels"]])
 
-  rope.line.alpha <- 1.25 * rope_alpha
+  rope.line.alpha <- 1.25 * alpha_rope
   if (rope.line.alpha > 1) rope.line.alpha <- 1
 
   insight::check_if_installed("ggridges")
 
-  p <- ggplot(tmp, aes(x = estimate, y = predictor, fill = grp)) +
+  p <- ggplot(tmp, aes(x = .data$estimate, y = .data$predictor, fill = .data$grp)) +
     annotate(
       "rect",
       xmin = .rope[1],
       xmax = .rope[2],
       ymin = 0,
       ymax = Inf,
-      fill = rope_color,
-      alpha = (rope_alpha / 3),
+      fill = color_rope,
+      alpha = (alpha_rope / 3),
       na.rm = TRUE
     ) +
     geom_vline(
       xintercept = .rope,
       linetype = "dashed",
-      colour = rope_color,
+      colour = color_rope,
       alpha = rope.line.alpha,
       na.rm = TRUE
     ) +
     geom_vline(
       xintercept = 0,
-      colour = rope_color,
+      colour = color_rope,
       linewidth = 0.8,
       alpha = rope.line.alpha,
       na.rm = TRUE
@@ -201,14 +201,12 @@ plot.see_equivalence_test <- function(x,
 }
 
 
-
-
 # data frame method --------------------------------
 
 #' @export
 plot.see_equivalence_test_df <- function(x,
-                                         rope_color = "#0171D3",
-                                         rope_alpha = 0.2,
+                                         color_rope = "#0171D3",
+                                         alpha_rope = 0.2,
                                          data = NULL,
                                          n_columns = 1,
                                          ...) {
@@ -277,32 +275,32 @@ plot.see_equivalence_test_df <- function(x,
   if ("legend.title" %in% names(add.args)) legend.title <- eval(add.args[["legend.title"]])
   if ("labels" %in% names(add.args)) axis_labels <- eval(add.args[["labels"]])
 
-  rope.line.alpha <- 1.25 * rope_alpha
+  rope.line.alpha <- 1.25 * alpha_rope
 
   if (rope.line.alpha > 1) rope.line.alpha <- 1
 
   insight::check_if_installed("ggridges")
 
-  p <- ggplot(tmp, aes(x = estimate, y = predictor, fill = grp)) +
+  p <- ggplot(tmp, aes(x = .data$estimate, y = .data$predictor, fill = .data$grp)) +
     annotate(
       "rect",
       xmin = .rope[1],
       xmax = .rope[2],
       ymin = 0,
       ymax = Inf,
-      fill = rope_color,
-      alpha = (rope_alpha / 3)
+      fill = color_rope,
+      alpha = (alpha_rope / 3)
     ) +
     geom_vline(
       xintercept = .rope,
       linetype = "dashed",
-      colour = rope_color,
+      colour = color_rope,
       alpha = rope.line.alpha,
       na.rm = TRUE
     ) +
     geom_vline(
       xintercept = 0,
-      colour = rope_color,
+      colour = color_rope,
       linewidth = 0.8,
       alpha = rope.line.alpha,
       na.rm = TRUE
@@ -326,15 +324,14 @@ plot.see_equivalence_test_df <- function(x,
 }
 
 
-
 # freq models method --------------------------------
 
 #' @rdname plot.see_equivalence_test
 #' @export
 plot.see_equivalence_test_lm <- function(x,
                                          size_point = 0.7,
-                                         rope_color = "#0171D3",
-                                         rope_alpha = 0.2,
+                                         color_rope = "#0171D3",
+                                         alpha_rope = 0.2,
                                          show_intercept = FALSE,
                                          n_columns = 1,
                                          ...) {
@@ -393,17 +390,17 @@ plot.see_equivalence_test_lm <- function(x,
   if ("x.title" %in% names(add.args)) x.title <- eval(add.args[["x.title"]])
   if ("legend.title" %in% names(add.args)) legend.title <- eval(add.args[["legend.title"]])
 
-  rope.line.alpha <- 1.25 * rope_alpha
+  rope.line.alpha <- 1.25 * alpha_rope
   if (rope.line.alpha > 1) rope.line.alpha <- 1
 
   p <- ggplot(
     x,
     aes(
-      y = Parameter,
-      x = Estimate,
-      xmin = CI_low,
-      xmax = CI_high,
-      colour = ROPE_Equivalence
+      y = .data$Parameter,
+      x = .data$Estimate,
+      xmin = .data$CI_low,
+      xmax = .data$CI_high,
+      colour = .data$ROPE_Equivalence
     )
   ) +
     annotate(
@@ -412,20 +409,20 @@ plot.see_equivalence_test_lm <- function(x,
       xmax = .rope[2],
       ymin = 0,
       ymax = Inf,
-      fill = rope_color,
-      alpha = (rope_alpha / 3)
+      fill = color_rope,
+      alpha = (alpha_rope / 3)
     ) +
     geom_vline(
       xintercept = .rope,
       linetype = "dashed",
-      colour = rope_color,
+      colour = color_rope,
       linewidth = 0.8,
       alpha = rope.line.alpha,
       na.rm = TRUE
     ) +
     geom_vline(
       xintercept = 0,
-      colour = rope_color,
+      colour = color_rope,
       linewidth = 0.8,
       alpha = rope.line.alpha,
       na.rm = TRUE
