@@ -85,7 +85,6 @@ data_plot.n_factors <- function(x, data = NULL, type = "bar", ...) {
 data_plot.n_clusters <- data_plot.n_factors
 
 
-
 # Plot --------------------------------------------------------------------
 
 #' Plot method for numbers of clusters to extract or factors to retain
@@ -142,16 +141,16 @@ plot.see_n_factors <- function(x,
       geom_segment(
         data = segment_data,
         aes(
-          x = x_intercept,
-          xend = x_intercept,
+          x = .data$x_intercept,
+          xend = .data$x_intercept,
           y = 0,
-          yend = y_max
+          yend = .data$y_max
         ),
         color = flat_colors("red")
       ) +
       geom_point(
         data = segment_data,
-        aes(x = x_intercept, y = y_max),
+        aes(x = .data$x_intercept, y = .data$y_max),
         color = flat_colors("red")
       ) +
       scale_x_continuous(breaks = 1:max(x$x, na.rm = TRUE)) +
