@@ -119,7 +119,6 @@ data_plot.p_direction <- function(x, data = NULL, show_intercept = FALSE, ...) {
 }
 
 
-
 #' @keywords internal
 .compute_densities_pd <- function(x, name = "Y", null = 0) {
   out <- .as.data.frame_density(
@@ -139,7 +138,6 @@ data_plot.p_direction <- function(x, data = NULL, show_intercept = FALSE, ...) {
 }
 
 
-
 # Plot --------------------------------------------------------------------
 
 #' Plot method for probability of direction
@@ -166,7 +164,7 @@ plot.see_p_direction <- function(x,
                                  data = NULL,
                                  show_intercept = FALSE,
                                  priors = FALSE,
-                                 priors_alpha = 0.4,
+                                 alpha_priors = 0.4,
                                  n_columns = 1,
                                  ...) {
   # save model for later use
@@ -209,7 +207,7 @@ plot.see_p_direction <- function(x,
       model,
       parameter = params,
       show_intercept = show_intercept,
-      priors_alpha = priors_alpha
+      alpha_priors = alpha_priors
     )
   }
 
