@@ -35,14 +35,13 @@ scale_color_metro <- function(palette = "complement",
   pal <- palette_metro(palette = palette, reverse = reverse)
 
   if (discrete) {
-    discrete_scale(aesthetics = aesthetics, paste0("metro_", palette), palette = pal, ...)
+    discrete_scale(aesthetics = aesthetics, palette = pal, ...)
   } else {
     scale_color_gradientn(colours = pal(256), aesthetics = aesthetics, ...)
   }
 }
 
 
-
 # Aliases -----------------------------------------------------------------
 
 
@@ -91,13 +90,9 @@ scale_colour_metro_c <- scale_color_metro_c
 scale_colour_metro_d <- scale_color_metro_d
 
 
-
-
-
 # Fill --------------------------------------------------------------------
 
 
-
 #' @rdname scale_color_metro
 #' @export
 scale_fill_metro <- function(palette = "complement",
@@ -108,7 +103,7 @@ scale_fill_metro <- function(palette = "complement",
   pal <- palette_metro(palette = palette, reverse = reverse)
 
   if (discrete) {
-    discrete_scale(aesthetics = aesthetics, paste0("metro_", palette), palette = pal, ...)
+    discrete_scale(aesthetics = aesthetics, palette = pal, ...)
   } else {
     scale_fill_gradientn(colours = pal(256), aesthetics = aesthetics, ...)
   }
@@ -148,14 +143,9 @@ scale_fill_metro_c <- function(palette = "complement",
 }
 
 
-
-
-
 # Palette --------------------------------------------------------------------
 
 
-
-
 # The palette based on metro design colors: https://www.materialui.co/metrocolors
 metro_colors_list <- c(
   `red` = "#e51400",
@@ -200,8 +190,6 @@ metro_colors <- function(...) {
 }
 
 
-
-
 metro_palettes <- list(
   `full` = metro_colors(),
   `ice` = metro_colors("purple", "deep purple", "blue", "light blue"),
@@ -233,10 +221,6 @@ metro_palettes <- list(
 )
 
 
-
-
-
-
 #' Metro color palette
 #'
 #' The palette based on [Metro
